@@ -32,12 +32,11 @@ from flask import Flask, jsonify, make_response, request, send_from_directory
 from flask_cors import CORS
 from flask_socketio import SocketIO
 
-import covalent.executor as covalent_executor
 from covalent._results_manager import Result
 from covalent._results_manager import results_manager as rm
 from covalent._shared_files.config import get_config
 from covalent._shared_files.util_classes import Status
-from covalent._shared_files.utils import get_named_params
+from covalent_dispatcher._db.dispatchdb import DispatchDB
 from covalent_dispatcher._service.app import bp
 
 WEBHOOK_PATH = "/api/webhook"
@@ -68,107 +67,31 @@ def handle_draw_request():
 
 @app.route("/api/results")
 def list_results():
-    path = request.args["resultsDir"]
-    dispatch_ids = [dir for dir in os.listdir(path) if os.path.isdir(os.path.join(path, dir))]
-    return jsonify(dispatch_ids)
-
-
-def encode_result(obj):
-    if isinstance(obj, Status):
-        return obj.STATUS
-    if isinstance(obj, datetime):
-        return obj.isoformat()
-    return str(obj)
-
-
-def extract_graph_node(node):
-    # doc string
-    f = node.get("function")
-    if f is not None:
-        node["doc"] = node["function"].get_deserialized().__doc__
-
-    # metadata
-    extract_executor_info(node.get("metadata"))
-
-    # prevent JSON encoding
-    node["kwargs"] = encode_dict(node.get("kwargs"))
-
-    # remove unused fields
-    node.pop("function", None)
-    node.pop("node_name", None)
-
-    return node
-
-
-def encode_dict(d):
-    """Avoid JSON encoding when python str() suffices"""
-    if not isinstance(d, dict):
-        return d
-    return {k: str(v) for (k, v) in d.items()}
-
-
-def extract_executor_info(metadata):
-    # executor details
-    try:
-        name = metadata["executor"]
-        executor = covalent_executor._executor_manager.get_executor(name=name)
-
-        if executor is not None:
-            # extract attributes
-            metadata["executor"] = encode_dict(executor.__dict__)
-            if isinstance(name, str):
-                metadata["executor_name"] = name
-            else:
-                metadata["executor_name"] = f"<{executor.__class__.__name__}>"
-    except (KeyError, AttributeError):
-        pass
-
-
-def extract_graph(graph):
-    graph = nx.json_graph.node_link_data(graph)
-    nodes = list(map(extract_graph_node, graph["nodes"]))
-    return {
-        "nodes": nodes,
-        "links": graph["links"],
-    }
+    with DispatchDB() as db:
+        res = db.get()
+    if not res:
+        return jsonify([])
+    else:
+        return jsonify([simplejson.loads(r[1]) for r in res])
 
 
 @app.route("/api/results/<dispatch_id>")
 def fetch_result(dispatch_id):
-    results_dir = request.args["resultsDir"]
-
-    result = rm.get_result(dispatch_id, results_dir=results_dir)
-    extract_executor_info(result.lattice.metadata)
-
-    lattice = result.lattice
-    ((named_args, named_kwargs),) = (
-        get_named_params(lattice.workflow_function, lattice.args, lattice.kwargs),
-    )
-
-    response = {
-        "dispatch_id": result.dispatch_id,
-        "status": result.status,
-        "result": result.result,
-        "start_time": result.start_time,
-        "end_time": result.end_time,
-        "results_dir": result.results_dir,
-        "error": result.error,
-        "lattice": {
-            "function_string": lattice.workflow_function_string,
-            "doc": lattice.__doc__,
-            "name": lattice.__name__,
-            "inputs": encode_dict({**named_args, **named_kwargs}),
-            "metadata": lattice.metadata,
-        },
-        "graph": extract_graph(result.lattice.transport_graph._graph),
-    }
-
-    # Use simplejson/ignore_nan=True to handle NaN/Infinity constants
-    response = simplejson.dumps(response, default=encode_result, ignore_nan=True)
+    with DispatchDB() as db:
+        res = db.get([dispatch_id])
+    response = res[0][1]
 
     return app.response_class(response, status=200, mimetype="application/json")
 
 
+@app.route("/api/results", methods=["DELETE"])
+def delete_results():
+    dispatch_ids = request.json.get("dispatchIds", [])
+    with DispatchDB() as db:
+        db.delete(dispatch_ids)
+    return jsonify({"ok": True})
+
+
 @app.route("/api/logoutput/<dispatch_id>")
 def fetch_file(dispatch_id):
     path = request.args.get("path")
@@ -230,4 +153,4 @@ if __name__ == "__main__":
     else:
         port = DEFAULT_PORT
     debug = True if args.develop is True else False
-    socketio.run(app, debug=debug, host="0.0.0.0", port=port)
+    socketio.run(app, debug=debug, host="0.0.0.0", port=port, use_reloader=True)
